package com.zilber.boot.module.booking.controller;

import com.zilber.boot.module.booking.form.ApprovalForm;
import com.zilber.boot.module.booking.form.add.BookingAF;
import com.zilber.boot.module.booking.form.modify.BookingMF;
import com.zilber.boot.module.booking.form.pr.BookingPR;
import com.zilber.boot.module.booking.service.BookingService;
import com.zilber.boot.utils.AjaxResult;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.io.Serializable;
import java.util.List;

/**
 * 预约记录(Booking)表控制层
 *
 * @author liuao
 * @since 2025-04-25 15:50:18
 */
@RestController
@RequestMapping("/booking")
@Api(tags = "预约记录管理")
public class BookingController
{

    @Autowired
    private BookingService service;

    @PostMapping
    @ApiOperation("添加预约记录")
    public AjaxResult addBooking(@RequestBody BookingAF form)
    {
        return new AjaxResult(service.addBooking(form));
    }

    @PutMapping
    @ApiOperation("修改预约记录信息")
    public AjaxResult updBooking(@RequestBody BookingMF form)
    {
        return new AjaxResult(service.updBooking(form));
    }

    @PutMapping("/approve")
    @ApiOperation("审批预约")
    public AjaxResult approve(@RequestBody ApprovalForm form)
    {
        return new AjaxResult(service.approve(form));
    }

    @GetMapping("/{id}")
    @ApiOperation("获取单挑预约信息")
    public AjaxResult getBooking(@PathVariable Serializable id)
    {
        return AjaxResult.success(service.getBooking(id));
    }

    @GetMapping
    @ApiOperation("分页请求")
    public AjaxResult getPage(BookingPR pr)
    {
        return AjaxResult.success(service.getPage(pr));
    }

    @DeleteMapping
    @ApiOperation("删除单条预约记录")
    public AjaxResult deleteBooking(@RequestBody BookingMF form)
    {
        return new AjaxResult(service.deleteBooking(form));
    }

    @DeleteMapping("/s")
    @ApiOperation("批量删除预约记录")
    public AjaxResult deleteBookings(@RequestBody List<Serializable> idList)
    {
        return new AjaxResult(service.deleteBookings(idList));
    }

}

