package com.zilber.boot.module.booking.form.add;

import com.fasterxml.jackson.annotation.JsonFormat;
import com.zilber.boot.module.booking.enums.BookingType;
import com.zilber.boot.module.booking.enums.InspectionMethod;
import com.zilber.boot.module.booking.form.BookingForm;
import com.zilber.boot.module.booking.group.Me;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.AllArgsConstructor;
import lombok.Data;
import lombok.NoArgsConstructor;
import org.springframework.format.annotation.DateTimeFormat;

import javax.validation.constraints.Min;
import javax.validation.constraints.NotBlank;
import javax.validation.constraints.NotNull;
import java.util.Date;

/**
 * @Author LJX
 * @TIME 2025-04-27 9:12
 * @PROJECT termicheck-platform
 * created by Intellij IDEA
 * Description
 */
@Data
@NoArgsConstructor
@AllArgsConstructor
@ApiModel("预约记录添加表单")
public class BookingAF
        extends BookingForm
{

    /**
     * 厂家id
     */
    @ApiModelProperty(value = "厂家id")
    @NotNull(message = "厂家id不能为空")
    private Long factoryId;
    /**
     * 预约类型（1-省招检测，2-厂家委托）
     */
    @ApiModelProperty(value = "预约类型（1-省招检测，2-厂家委托）")
    @NotNull(message = "预约类型不能为空")
    private BookingType bookingType;
    /**
     * 检测方式（1-全检，2-抽检）
     */
    @ApiModelProperty(value = "检测方式（1-全检，2-抽检）")
    @NotNull(message = "检测方式不能为空")
    private InspectionMethod inspectionMethod;
    /**
     * 设备数量
     */
    @ApiModelProperty(value = "设备数量")
    @NotNull(message = "设备数量不能为空")
    @Min(value = 1, message = "设备数量不能小于0")
    private Integer equipNum;
    /**
     * 设备类型
     */
    @ApiModelProperty(value = "设备类型")
    @NotNull(message = "设备类型不能为空")
    @NotBlank(message = "设备类型不能为空")
    private String equipType;
    /**
     * 预约检测日期
     */
    @ApiModelProperty(value = "预约检测日期")
    @NotNull(message = "预约检测日期不能为空")
    @DateTimeFormat(pattern = "yyyy-MM-dd")
    @JsonFormat(pattern = "yyyy-MM-dd")
    private Date inspectionDate;
    /**
     * 备注
     */
    @ApiModelProperty(value = "备注")
    private String remark;
    /**
     * 中标通知书路径
     */
    @ApiModelProperty(value = "中标通知书路径")
    @NotNull(message = "中标通知书不能为空", groups = Me.class)
    @NotBlank(message = "中标通知书不能为空", groups = Me.class)
    private String loaUrl;
    /**
     * 地市公司
     */
    @ApiModelProperty(value = "地市公司")
    @NotNull(message = "地市公司不能为空", groups = Me.class)
    @NotBlank(message = "地市公司不能为空", groups = Me.class)
    private String localOffice;
    /**
     * 中标类型
     */
    @ApiModelProperty(value = "中标类型")
    @NotNull(message = "中标类型不能为空", groups = Me.class)
    @NotBlank(message = "中标类型不能为空", groups = Me.class)
    private String loaType;
    /**
     * 涉及工程类型
     */
    @ApiModelProperty(value = "涉及工程项目")
    @NotNull(message = "涉及工程项目不能为空", groups = Me.class)
    @NotBlank(message = "涉及工程项目不能为空", groups = Me.class)
    private String projectName;
    /**
     * 招标批次
     */
    @ApiModelProperty(value = "招标批次")
    @NotNull(message = "招标批次不能为空", groups = Me.class)
    private Integer bidBatch;

}
