package com.zilber.boot.module.booking.pojo;

import com.baomidou.mybatisplus.annotation.IdType;
import com.baomidou.mybatisplus.annotation.TableId;
import com.baomidou.mybatisplus.annotation.TableName;
import com.zilber.boot.module.booking.enums.ApprovalStatus;
import com.zilber.boot.module.booking.form.add.BookingAF;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.AllArgsConstructor;
import lombok.Data;
import lombok.NoArgsConstructor;
import org.springframework.beans.BeanUtils;

import java.io.Serializable;
import java.util.Calendar;
import java.util.Date;

/**
 * 预约记录(Booking)实体类
 *
 * @author liuao
 * @since 2025-04-25 15:49:55
 */
@Data
@NoArgsConstructor
@AllArgsConstructor
@ApiModel("预约记录")
@TableName("tc_booking")
public class Booking implements Serializable
{
    private static final long serialVersionUID = -37467439775541824L;
    /**
     * id
     */
    @ApiModelProperty(value = "id")
    @TableId(type = IdType.AUTO)
    private Long id;
    /**
     * 厂家id
     */
    @ApiModelProperty(value = "厂家id")
    private Long factoryId;
    /**
     * 预约类型（1-省招检测，2-厂家委托）
     */
    @ApiModelProperty(value = "预约类型（1-省招检测，2-厂家委托）")
    private String bookingType;
    /**
     * 检测方式（1-全检，2-抽检）
     */
    @ApiModelProperty(value = "检测方式（1-全检，2-抽检）")
    private String inspectionMethod;
    /**
     * 设备数量
     */
    @ApiModelProperty(value = "设备数量")
    private Integer equipNum;
    /**
     * 设备类型
     */
    @ApiModelProperty(value = "设备类型")
    private String equipType;
    /**
     * 预约检测日期
     */
    @ApiModelProperty(value = "预约检测日期")
    private Date inspectionDate;
    /**
     * 备注
     */
    @ApiModelProperty(value = "备注")
    private String remark;
    /**
     * 中标通知书路径
     */
    @ApiModelProperty(value = "中标通知书路径")
    private String loaUrl;
    /**
     * 地市公司
     */
    @ApiModelProperty(value = "地市公司")
    private String localOffice;
    /**
     * 中标类型
     */
    @ApiModelProperty(value = "中标类型")
    private String loaType;
    /**
     * 涉及工程类型
     */
    @ApiModelProperty(value = "涉及工程类型")
    private String projectName;
    /**
     * 招标批次
     */
    @ApiModelProperty(value = "招标批次")
    private Integer bidBatch;
    /**
     * 审批状态
     */
    @ApiModelProperty("审批状态（0-待批，1-通过，2-驳回）")
    private String approvalStatus;
    /**
     * 驳回理由
     */
    @ApiModelProperty("驳回理由")
    private String rejectReason;
    /**
     * 审批时间
     */
    @ApiModelProperty("审批时间")
    private Date approveTime;
    /**
     * 检测状态（0-待检，1-通过，2-不通过）
     */
    @ApiModelProperty("检测状态（0-待检，1-通过，2-不通过）")
    private String inspectionStatus;
    /**
     * 检测时间
     */
    @ApiModelProperty("检测时间")
    private Date inspectionExeDate;
    /**
     * 创建者id
     */
    @ApiModelProperty(value = "创建者id")
    private Long creatorId;
    /**
     * 创建时间
     */
    @ApiModelProperty(value = "创建时间")
    private Date creationTime;
    /**
     * 修改人id
     */
    @ApiModelProperty(value = "修改人id")
    private Long updaterId;
    /**
     * 修改时间
     */
    @ApiModelProperty(value = "修改时间")
    private Date updateTime;

    public Booking(BookingAF form, Long userId)
    {
        Calendar instance = Calendar.getInstance();
        Date now = new Date();
        BeanUtils.copyProperties(form, this);
        this.bookingType = form.getBookingType().getCode();
        this.inspectionMethod = form.getInspectionMethod().getCode();
        instance.setTime(form.getInspectionDate());
        instance.set(Calendar.HOUR_OF_DAY, 0);
        instance.set(Calendar.MINUTE, 0);
        instance.set(Calendar.SECOND, 0);
        this.inspectionDate = instance.getTime();
        //预约审批状态为待批
        this.approvalStatus = ApprovalStatus.NONE.getCode();
        //
        this.creatorId = userId;
        this.updaterId = userId;
        this.creationTime = now;
        this.updateTime = now;
    }

}

